function Visualize_Grid(prmLTEPDSCH)
% VISUALIZE_GRID. In this function a resource grid with each kind of signal is displayed
%% Adapt input variables to the initial code.
nS = prmLTEPDSCH.nS;
Nrb = prmLTEPDSCH.Nrb;                          
Nrb_sc = prmLTEPDSCH.Nrb_sc;                 % 12 for normal mode
Ndl_symb = prmLTEPDSCH.Ndl_symb;         % 7    for normal mode
numContSymb    = prmLTEPDSCH.contReg;  % either {1, 2, 3}
rows = Nrb*Nrb_sc;
columns = Ndl_symb*2;
X = [1.5 columns+0.5];
Y = [1.5 rows+0.5];
%% Specify resource grid location indices for CSR, PDCCH, PDSCH, PBCH, PSS, SSS
% 1st: Indices for CSR pilot symbols
lenOFDM = Nrb*Nrb_sc; %OFDM lenght
idx            = 1:lenOFDM;
idx_csr0   = 1:6:lenOFDM;              % More general starting point = 1+mod(NcellID, 6);
idx_csr4   = 4:6:lenOFDM;              % More general starting point = 1+mod(3+NcellID, 6);
idx_csr     =[idx_csr0, 4*lenOFDM+idx_csr4, 7*lenOFDM+idx_csr0, 11*lenOFDM+idx_csr4];
% 2nd: Indices for PDCCH control data symbols
ContREs=numContSymb*lenOFDM;
idx_dci=1:ContREs;
idx_pdcch = ExpungeFrom(idx_dci,idx_csr0);
% 3rd: Indices for PDSCH and PDSCH data in OFDM symbols whee pilots are present
idx_data0= ExpungeFrom(idx,idx_csr0);
idx_data4 = ExpungeFrom(idx,idx_csr4);
%% Handle 3 types of subframes differently
switch nS
    % 4th: Indices for BCH, PSS, SSS are only found in specific subframes 0 and 5
    % Thsese symbols share the same 6 center sub-carrier locations (idx_ctr)
    % and differ in OFDM symbol number.
    case 0    % Subframe 0
        % PBCH, PSS, SSS are available + CSR, PDCCH, PDSCH
        idx_6rbs = (1:72);
        idx_ctr = 0.5* lenOFDM - 36 + idx_6rbs ;
        idx_SSS  = 5* lenOFDM + idx_ctr;
        idx_PSS  = 6* lenOFDM + idx_ctr;
        idx_ctr0 = ExpungeFrom(idx_ctr,idx_csr0);
        idx_bch = [7*lenOFDM + idx_ctr0,8*lenOFDM + idx_ctr,...
            9*lenOFDM + idx_ctr, 10*lenOFDM + idx_ctr];
        idx_data5   = ExpungeFrom(idx,idx_ctr);
        idx_data7 = ExpungeFrom(idx_data0,idx_ctr);
        idx_data   = [ContREs+1:4*lenOFDM,   4*lenOFDM+idx_data4, ...
            5*lenOFDM+idx_data5, 6*lenOFDM+idx_data5,  7*lenOFDM+idx_data7, 8*lenOFDM+idx_data5, ...
            9*lenOFDM+idx_data5, 10*lenOFDM+idx_data5, 11*lenOFDM+idx_data4, ...
            12*lenOFDM+1:14*lenOFDM];
        %Now the purpose is to use the index to place a number in each kind of cell
        rg = zeros(rows, columns);
        rg(idx_data)=1; 
        rg(idx_csr)=2;             
        rg(idx_pdcch)=3;   
        rg(idx_PSS)=4;                 
        rg(idx_SSS)=5;             
        rg(idx_bch)=6;
        image(X,Y,rg);
        title('Resource grid for Subframe 0');

    case 10  % Subframe 5
        % PSS, SSS are available + CSR, PDCCH, PDSCH
        % Primary ans Secondary synchronization signals in OFDM symbols 5 and 6
        idx_6rbs = (1:72);
        idx_ctr = 0.5* lenOFDM - 36 + idx_6rbs ;
        idx_SSS  = 5* lenOFDM + idx_ctr;
        idx_PSS  = 6* lenOFDM + idx_ctr;
        idx_data5 = ExpungeFrom(idx,idx_ctr);
        idx_data   = [ContREs+1:4*lenOFDM, 4*lenOFDM+idx_data4,  5*lenOFDM+idx_data5, 6*lenOFDM+idx_data5, ...
            7*lenOFDM+idx_data0, 8*lenOFDM+1:11*lenOFDM,  11*lenOFDM+idx_data4, ...
            12*lenOFDM+1:14*lenOFDM];
        rg = zeros(rows, columns);
        rg(idx_data)=1; 
        rg(idx_csr)=2;             
        rg(idx_pdcch)=3;   
        rg(idx_PSS)=4;                 
        rg(idx_SSS)=5; 
        image(X,Y,rg);
        title('Resource grid for Subframe 5');
    otherwise % other subframes
        % Only CSR, PDCCH, PDSCH
        idx_data = [ContREs+1:4*lenOFDM, 4*lenOFDM+idx_data4, ...
            5*lenOFDM+1:7*lenOFDM, ...
            7*lenOFDM+idx_data0, ...
            8*lenOFDM+1:11*lenOFDM, ...
            11*lenOFDM+idx_data4, ...
            12*lenOFDM+1:14*lenOFDM];
        rg = zeros(rows, columns);
        rg(idx_data)=1; 
        rg(idx_csr)=2;             
        rg(idx_pdcch)=3;   
        image(X,Y,rg);
        title('Resource grid for Subframe 1,2,3,4,6,7,8,9');
end
% Legend for each kind of signal
% 1 = user data (PDSCH) : 'clar' blau
% 2 = csr : orangge coloured
% 3 = pdcch : white coloured
% 4 = pss : red coloured
% 5 = sss : blue coloured
% 6 = bch : green coloured
map =[0.7,1,1
    1,0.5,0
    0,0,0
    1,0,0
    0,0,1
    0,1,0];
% Apply the colormap and show the colorbar
axis square
xlabel('Number of OFDM symbol'); ylabel('Number of subcarrier');
set(gca,'YDir','normal');
colormap(map);
labels = {'User Data','CSR','PDCCH','PSS','SSS','BCH'};
lcolorbar(labels,'fontweight','bold');
end
