function LTE_SISO_GUI () %BOC
%% Define struct that chan be access from any callback function
data = struct('channelBW', 6, 'modulationType', 2, 'SNR', 50,...
               'visualsOn', 0, 'channel_type', 1, 'Eqmode', 1,...
               'transmission_chain',4);
%% Construct the components
f = figure('Visible','on','Name','GUI', 'CloseRequestFcn', @quit, 'Position',[400,100,500,600]);
t_title = uicontrol(f, 'Style', 'text', 'String','Choose the desired parameters for different LTE transmission chains',...
        'Position', [10 500 400 40]);                
t_txch = uicontrol(f, 'Style', 'text', 'String', 'Select one of these transmission chains',...
                        'Position',[30 450 230 40]);
e_txch = uicontrol(f, 'Style', 'popupmenu', 'Callback', @select_transmissionchain,...
        'String', {'SISO_BASIC', 'SISO_PHASE_COMPENSATOR', 'SISO_CHANNEL_ESTIMATION', 'SISO_COMPLETE'},...
        'Position', [30 400 230 40]);
t_mod = uicontrol(f,'Style','text', 'String','Select modulation type',...
                    'Position',[30 350 130 40]);  
e_mod = uicontrol(f,'Style', 'popupmenu', 'Callback', @select_modulation,...
                'String', {'QPSK', '16QAM', '64QAM'},...
                'Position',[30 300 130 40],'Tag','popupmenu2');
t_chanBW = uicontrol(f,'Style','text', 'String','Select channel bandwidth (MHz)',...
                    'Position',[30 250 130 40]);
e_chanBW = uicontrol(f,'Style','popupmenu', 'Callback', @select_chanBW,...
                    'String',{'1.4','3','5','10','15','20'},...
                    'Position',[30 200 130 40],'Tag','popumpmenu1');
t_chantype = uicontrol(f,'Style','text', 'String','Select one channel type',...
                    'Position',[30 150 130 40]);  
e_chantype = uicontrol(f,'Style', 'popupmenu', 'Callback', @select_channeltype,...
                'String', {'flat-low-mobility', 'flat-high-mobility','frequency-selective-low-mobility',...
                'frequency-selective-high-mobility'},'Position',[30 100 130 40],'Tag','popupmenu2');
visual = uicontrol(f, 'Style', 'checkbox', 'String', 'display spectrum & constellation',...
                'Value',0,'callback', @dis_cons_spec,'Position', [30 50 230 40]);
t_SNR = uicontrol(f,'Style','text', 'String','Select SNR (dB)',...
                    'Position',[200 350 130 40]);
e_SNR = uicontrol(f, 'Style', 'edit', 'Callback', @select_SNR,...
                    'Position', [200 320 130 20]);
t_Eqmode = uicontrol(f,'Style','text', 'String','Select Equalization mode',...
                    'Position',[200 250 130 40]);
e_Eqmode = uicontrol(f,'Style','popupmenu', 'Callback', @select_Eqmode,...
                    'String',{'ZF','MMSE'},'Position',[200 200 130 40]);              
push = uicontrol(f, 'Style', 'pushbutton', 'Callback', @run_simulation,...
                'String', 'Start', 'Position',[200 100 130 100]);            

%% Write Callbacks
function dis_cons_spec (hObject, callbackdata)
    data.visualsOn = hObject.Value;
end
function select_transmissionchain(hObject, callbackdata)
data.transmission_chain = hObject.Value;
    switch  data.transmission_chain 
        case 2
            set(e_chantype,'String',{'flat-low-mobility','flat-high-mobility'});
            set(e_Eqmode, 'enable', 'Off');
        case 4            
            set(e_Eqmode, 'enable', 'On');
            set(e_chantype, 'String', {'flat-low-mobility', 'flat-high-mobility','frequency-selective-low-mobility',...
                'frequency-selective-high-mobility'});
        otherwise 
            set(e_Eqmode, 'enable', 'Off');
            set(e_chantype, 'String', {'flat-low-mobility', 'flat-high-mobility','frequency-selective-low-mobility',...
                'frequency-selective-high-mobility'});
    end
end
function select_channeltype(hObject, callbackdata)
data.channel_type = hObject.Value;
end
function select_chanBW(hObject, callbackdata)
chanString = hObject.String;
chanValue = hObject.Value;
switch chanString{chanValue}
    case '1.4'
        data.channelBW = 1;
    case '3'
         data.channelBW = 2;
    case '5'
         data.channelBW = 3;
    case '10'
         data.channelBW = 4;
    case '15'
         data.channelBW = 5;
    case '20'
         data.channelBW = 6;
end
end
function select_modulation(hObject, callbackdata)
modString = hObject.String;
modValue = hObject.Value;
switch modString{modValue}
    case 'QPSK'
        data.modulationType = 1;
    case '16QAM'
        data.modulationType = 2;
    case '64QAM' 
        data.modulationType = 3;
end 
end
function select_Eqmode(hObject, callbackdata)
EqmodeString = hObject.String;
EqmodeValue = hObject.Value;
switch EqmodeString{EqmodeValue}
    case 'ZF'
        data.Eqmode = 1;
    case 'MMSE'
        data.Eqmode = 2;
end 
end
function select_SNR(hObject, callbackdata)
data.SNR = str2double(hObject.String);
end

function run_simulation(hObject, callbackdata)
%display(data);
par = parameters(data);
[prmLTEPDSCH, prmLTEDLSCH, prmMdl] = initialize(par);
zReport_data_rate(prmLTEDLSCH, prmLTEPDSCH);
tic;
    hPBer = comm.ErrorRate;
    maxNumErrs=prmMdl.maxNumErrs;
    maxNumBits=prmMdl.maxNumBits;
    %% Simulation loop
    nS = 0; % Slot number, one of [0:2:18]
    Measures = zeros(3,1); %initialize BER output
    while (( Measures(2)< maxNumErrs) && (Measures(3) < maxNumBits))
        [dataIn, dataOut, txSig, rxSig, dataRx, yRec, csr] = ...
            SISO_step(nS, par.snrdB, prmLTEDLSCH, prmLTEPDSCH, prmMdl, par.txch);
        % Calculate  bit errors
        Measures = step(hPBer, dataIn, dataOut);
        %Visualize constellation % spectrum
        if par.visualsOn
            zVisualize( prmLTEPDSCH, txSig, rxSig, yRec, dataRx, csr, nS, par.txch);
        end;
        % Update subframe number
        nS = nS + 2; if nS > 19, nS = mod(nS, 20); end;
    end
    ber=Measures(1);
    display(ber);
toc;
clear functions;
end
    function quit(hObject, Callbackdata)
        clear functions;
        close(gcf);
    end
end %EOC
