function [dataIn, dataOut, txSig, rxSig, dataRx, yRec, csr_ref]...
    = SISO_step(nS, snrdB, prmLTEDLSCH, prmLTEPDSCH, prmMdl, txch)
%Common for all tx chains
%% TX
%  Generate payload
dataIn = genPayload(nS,  prmLTEDLSCH.TBLenVec);
% Transport block CRC generation
tbCrcOut1 =CRCgenerator(dataIn);
% Channel coding includes - CB segmentation, turbo coding, rate matching,
% bit selection, CB concatenation - per codeword
[data, Kplus1, C1] = lteTbChannelCoding(tbCrcOut1, nS, prmLTEDLSCH, prmLTEPDSCH);
%Scramble codeword
scramOut = lteScramble(data, nS, 0, prmLTEPDSCH.maxG);
% Modulate
modOut = Modulator(scramOut, prmLTEPDSCH.modType);
% Generate Cell-Specific Reference (CSR) signals
csr = CSRgenerator(nS, prmLTEPDSCH.numTx);
% Resource grid filling
E=8*prmLTEPDSCH.Nrb;
csr_ref=reshape(csr(1:E),2*prmLTEPDSCH.Nrb,4);
txGrid = REmapper_1Tx(modOut, csr_ref, nS, prmLTEPDSCH);
% OFDM transmitter
txSig = OFDMTx(txGrid, prmLTEPDSCH);
%Not common for all tx chains 
switch txch
    case 1
        %% Channel
        % SISO Fading channel
        [rxFade, chPathG] = MIMOFadingChan(txSig, prmLTEPDSCH, prmMdl);
        % Add AWG noise
        nVar = 10.^(0.1.*(-snrdB));
        rxSig =  AWGNChannel(rxFade, nVar);
        %% RX
        % OFDM Rx
        rxGrid = OFDMRx(rxSig, prmLTEPDSCH);
        % updated for numLayers -> numTx
        [dataRx, csrRx, idx_data] = REdemapper_1Tx(rxGrid, nS, prmLTEPDSCH);
        yRec = dataRx;
    case 2
        %% Channel
        % SISO Fading channel
        [rxFade, chPathG] = MIMOFadingChan(txSig, prmLTEPDSCH, prmMdl);
        % Balance out phase rotation due of Rayleigh Channel
        ang = phase(chPathG);
        complex = exp(-(1i).*ang);
        rxComp = rxFade.*complex;
        % Add AWG noise
        nVar = 10.^(0.1.*(-snrdB));
        rxSig =  AWGNChannel(rxComp, nVar);
        %% RX
        % OFDM Rx
        rxGrid = OFDMRx(rxSig, prmLTEPDSCH);
        % updated for numLayers -> numTx
        [dataRx, csrRx, idx_data] = REdemapper_1Tx(rxGrid, nS, prmLTEPDSCH);
        yRec =dataRx;
    case 3
        %%Channel
        % SISO Fading channel
        [rxFade, chPathG] = MIMOFadingChan(txSig, prmLTEPDSCH, prmMdl);
        % Add AWG noise
        nVar = 10.^(0.1.*(-snrdB));
        rxSig =  AWGNChannel(rxFade, nVar);
        %% RX
        % OFDM Rx
        rxGrid = OFDMRx(rxSig, prmLTEPDSCH);
        % updated for numLayers -> numTx
        [dataRx, csrRx, idx_data] = REdemapper_1Tx(rxGrid, nS, prmLTEPDSCH);
        % MIMO channel estimation
        if prmMdl.chEstOn
            chEst = ChanEstimate_1Tx(prmLTEPDSCH, csrRx,  csr_ref, 'interpolate');
            hD=chEst(idx_data);
        end
        %Basic equalization
        yRec = dataRx./hD;
    case 4
        %% Channel
        % SISO Fading channel
        [rxFade, chPathG] = MIMOFadingChan(txSig, prmLTEPDSCH, prmMdl);
                % Add AWG noise
        nVar = 10.^(0.1.*(-snrdB));
        rxSig =  AWGNChannel(rxFade, nVar);  
        %% RX
        % OFDM Rx
        rxGrid = OFDMRx(rxSig, prmLTEPDSCH);
        % updated for numLayers -> numTx
        [dataRx, csrRx, idx_data] = REdemapper_1Tx(rxGrid, nS, prmLTEPDSCH);
        % MIMO channel estimation
        if prmMdl.chEstOn
            chEst = ChanEstimate_1Tx(prmLTEPDSCH, csrRx,  csr_ref, 'interpolate');
            hD=chEst(idx_data);
        end
        % Frequency-domain equalizer
        yRec = Equalizer(dataRx, hD, nVar, prmLTEPDSCH.Eqmode);
end
%Common for all tx chains
% Demodulate
demodOut = DemodulatorSoft(yRec, prmLTEPDSCH.modType, nVar);
% Descramble both received codewords
rxCW =  lteDescramble(demodOut, nS, 0, prmLTEPDSCH.maxG);
% Channel decoding includes - CB segmentation, turbo decoding, rate dematching
[decTbData1, ~,~] = lteTbChannelDecoding(nS, rxCW, Kplus1, C1,  prmLTEDLSCH, prmLTEPDSCH);
% Transport block CRC detection
[dataOut, ~] = CRCdetector(decTbData1);
end