function [y, yPg] = MIMOFadingChan(in, prmLTE, prmMdl)
% MIMOFadingChan
%#codegen
% Get simulation params
numTx         = prmLTE.numTx;
numRx         = prmLTE.numRx;
chanMdl      = prmMdl.chanMdl;
chanSRate   = prmLTE.chanSRate;

switch chanMdl
    case 'flat-low-mobility',
        PathDelays = 0*(1/chanSRate);
        PathGains  = 0;
        Doppler=0;
    case 'flat-high-mobility',
        PathDelays = 0*(1/chanSRate);
        PathGains  = 0;
        Doppler=50;
    case 'frequency-selective-low-mobility',
        PathDelays = [0 10 20 30 100]*(1/chanSRate);
        PathGains  = [0 -3 -6 -8 -172];
        Doppler=0;
    case 'frequency-selective-high-mobility',
       PathDelays = [0 10 20 30 100]*(1/chanSRate);
        PathGains  = [0 -3 -6 -8 -172];
        Doppler=70;
    case 'frequency-selective-distortion-low-mobility'
       PathDelays = [0 30 90 150 300]*(1/chanSRate);
        PathGains  = [0 -3 -6 -8 -172];
        Doppler=0;
end
% Initialize objects
persistent chanObj;
if isempty(chanObj)
        chanObj = comm.MIMOChannel('SampleRate', chanSRate, ...
            'MaximumDopplerShift', Doppler, ...
            'PathDelays', PathDelays,...
            'AveragePathGains', PathGains,...
            'RandomStream', 'mt19937ar with seed',...
            'Seed', 100,...
            'TransmitCorrelationMatrix', eye(numTx),...
            'ReceiveCorrelationMatrix', eye(numRx),...
            'PathGainsOutputPort', true,...
            'NormalizePathGains', true,...
            'NormalizeChannelOutputs', true);
end
[y, yPg] = step(chanObj, in);

