function zVisualize(prmLTE, txSig, rxSig, yRec, dataRx, csr, nS)
% Constellation Scopes & Spectral Analyzers
persistent hScope1 hScope2 hSpecAnalyzer
if isempty(hSpecAnalyzer)
        mode=prmLTE.modType;
    switch mode
        case 1 % QPSK
            % Creates the modulation and display its constellation
            modulation=comm.PSKModulator(4, 'BitInput', true,'PhaseOffset', pi/4, 'SymbolMapping', 'Custom','CustomSymbolMapping', [0 2 3 1]);
            refC = constellation(modulation);
        case 2 % 16QAM
            % Creates the modulation and display its constellation
            modulation = comm.RectangularQAMModulator(16, 'BitInput',true,...
                                            'NormalizationMethod','Average power',...
                                            'SymbolMapping', 'Custom', ...
                                            'CustomSymbolMapping', [11 10 14 15 9 8 12 13 1 0 4 5 3 2 6 7]);
            refC = constellation(modulation);
        case 3 %64QAM
            % Creates the modulation and display its constellation
            modulation = comm.RectangularQAMModulator(64, 'BitInput',true,...
                                            'NormalizationMethod','Average power',...
                                            'SymbolMapping', 'Custom', ...
                                            'CustomSymbolMapping', [47 46 42 43 59 58 62 63 45 44 40 41 ...
                                                                    57 56 60 61 37 36 32 33 49 48 52 53 39 38 34 35 51 50 54 55 7 ...
                                                                    6 2 3 19 18 22 23 5 4 0 1 17 16 20 21 13 12 8 9 25 24 28 29 15 ...
                                                                    14 10 11 27 26 30 31]);   
            refC = constellation(modulation);
    end
    % Constellation Diagrams
    hScope1 = comm.ConstellationDiagram('ShowReferenceConstellation', true,...
        'ReferenceConstellation', refC,...
        'YLimits', [-2 2], 'XLimits', [-2 2], 'Position', ...
        figposition([5 60 20 25]), 'Name', 'Before Channel Estimation');
    hScope2 = comm.ConstellationDiagram( 'ShowReferenceConstellation', true,...
        'ReferenceConstellation', refC,...
        'YLimits', [-2 2], 'XLimits', [-2 2], 'Position', ...
        figposition([6 21 20 25]), 'Name', 'After Channel Estimation');
    if verLessThan('comm','5.5')
        hScope1.SymbolsToDisplay=prmLTE.numDataResources;
        hScope2.SymbolsToDisplay=prmLTE.numDataResources;
    end
    % Spectrum Scope
    hSpecAnalyzer = dsp.SpectrumAnalyzer('SampleRate',  prmLTE.chanSRate, ...
        'SpectrumType', 'Power density', 'PowerUnits', 'dBW', ...
        'RBWSource', 'Property',   'RBW', 15000,...
        'FrequencySpan', 'Span and center frequency',...
        'Span',  prmLTE.BW, 'CenterFrequency', 0,...
        'SpectralAverages', 10, ...
        'Title', 'Transmitted & Received Signal Spectrum', 'YLimits', [-110 -60],...
        'YLabel', 'PSD');
end
% Update Spectrum scope
% Received signal after equalization
yRecGrid = REmapper_1Tx(yRec, csr, nS, prmLTE);
yRecGridSig = OFDMTx(yRecGrid, prmLTE);
% Take certain symbols off a subframe only
step(hSpecAnalyzer, ...
    [SymbSpec(txSig, prmLTE), SymbSpec(rxSig, prmLTE), SymbSpec(yRecGridSig, prmLTE)]);
% Update Constellation Scope
if  (nS~=0 && nS~=10)
    step(hScope1, dataRx(:, 1));
    step(hScope2, yRec(:, 1));
end
end

function y = SymbSpec(in, prmLTE)
N = prmLTE.N;
cpLenR = prmLTE.cpLen0;
y = complex(zeros(N+cpLenR, 1));
% Use the first Tx/Rx antenna of the input for the display
y(:,1) = in(end-(N+cpLenR)+1:end, 1);
end